@@ -7,7 +7,7 @@ class HTTPException(Exception):
         self.response = response
 
 
-class ServiceUnavailable(Exception):
+class ServiceUnavailable(exceptions.ServiceUnavailable):
     def __init__(self, url):
         super(ServiceUnavailable, self).__init__(
             'Service Unavailable: %s' % url
