@@ -1,6 +1,6 @@
 import json_resource
 
-from json_resource_http.queryset import HTTPQuerySet
+from json_resource_http.queryset import HTTPQuerySet, AuthorizedQuerySet
 
 
 class HTTPResourceMeta(json_resource.StoredResourceMeta):
@@ -13,7 +13,7 @@ class HTTPResourceMeta(json_resource.StoredResourceMeta):
         result = json_resource.ResourceMeta.__new__(cls, name, bases, dct)
 
         if result.schema and not hasattr(result, 'objects'):
-            result.objects = HTTPQuerySet(
+            result.objects = result._query_set_class(
                 result
             )
 
@@ -23,6 +23,8 @@ class HTTPResourceMeta(json_resource.StoredResourceMeta):
 class Resource(json_resource.Resource):
     __metaclass__ = HTTPResourceMeta
 
+    _query_set_class = HTTPQuerySet
+
     def __init__(self, data, headers=None, **kwargs):
         self._headers = headers or {}
 
@@ -46,6 +48,18 @@ class Resource(json_resource.Resource):
             'content-type': 'application/json'
         }
 
-        headers.update(self._headers)
+        return headers
+
+
+class AuthorizedResource(Resource):
+    _query_set_class = AuthorizedQuerySet
+    token = None
+
+    @property
+    def headers(self):
+        headers = super(AuthorizedResource, self).headers
+
+        if self.token:
+            headers['Authorization'] = 'Bearer %s' % self.token['access_token']
 
         return headers
